function RGB2fluoData(aImarisApplicationID)

% Fill inner surface from clipped surfaces

%    <CustomTools>
%      <Menu>
%        <Item name="Remove white background" icon="Matlab" tooltip="Remove White Background from brightfield images">
%          <Command>MatlabXT::RGB2fluoData(%i)</Command>
%        </Item>
%      </Menu>
%    </CustomTools>
%
% Copyright (c) 2016, Dominic Filion


% Set up connection between Imaris and MATLAB
if isa(aImarisApplicationID, 'Imaris.IApplicationPrxHelper')
    vImarisApplication = aImarisApplicationID;
else
    % connect to Imaris interface
    javaaddpath ImarisLib.jar
    vImarisLib = ImarisLib;
    if ischar(aImarisApplicationID)
        aImarisApplicationID = round(str2double(aImarisApplicationID));
    end
    vImarisApplication = vImarisLib.GetApplication(aImarisApplicationID);
end


if vImarisApplication.GetDataSet.GetSizeC ~= 3
    msgbox('This image is not a color image having 3 colors');
    return
end
hw = waitbar(0,'Processing Files');

    aDataSet = vImarisApplication.GetDataSet.Clone;
    size(aDataSet.GetDataSliceFloats(0,0,0))
    xs = vImarisApplication.GetDataSet.GetSizeX;
    ys = vImarisApplication.GetDataSet.GetSizeY;
    cdata = zeros(xs,ys,3,'uint8');
    % cdata = zeros(size(aDataSet.GetDataSliceFloats(0,0,0)),'uint8');
    for chId = 1:3
        cdata(:,:,chId) = uint8(aDataSet.GetDataSliceFloats(0,chId-1,0));
    end
    NI = cdata;
    for chId = 1:3
        NI(:,:,chId) = cdata(:,:,chId) - min(cdata,[],3);
        aDataSet.SetDataSubSliceBytes(NI(:,:,chId),...
                    0, 0, 0, chId-1, 0);
    end
    vImarisApplication.SetDataSet(aDataSet);
    
close(hw);